##########################################################################
# (c) Copyright 2019 Hexoskin
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies. The
# software is provided "as is" and the author disclaims all warranties with
# regard to this software including all implied warranties of
# merchantability and fitness. In no event shall the author be liable for
# any special, direct, indirect, or consequential damages or any damages
# whatsoever resulting from loss of use, data or profits, whether in an
# action of contract, negligence or other tortious action, arising out of
# or in connection with the use or performance of this software.
###########################################################################

import os

from matplotlib import pyplot as plt

from .load_hx_data import load_np_data, getspec, get_status_info, filter_data

data_path = 'record_data'

x = load_np_data(os.path.join(data_path, 'acceleration_X'))
y = load_np_data(os.path.join(data_path, 'acceleration_Y.wav'))
z = load_np_data(os.path.join(data_path, 'acceleration_Z.wav'))
ecg = load_np_data(os.path.join(data_path, 'ECG_I.wav'))
ecg_info = getspec(os.path.join(data_path, 'ECG_I.wav'))

rr_interval = load_np_data(os.path.join(data_path, 'RR_interval.csv'))
heart_rate = load_np_data(os.path.join(data_path, 'heart_rate.wav'))
hr_info = getspec(os.path.join(data_path, 'heart_rate'))
heart_rate_quality = load_np_data(os.path.join(data_path, 'heart_rate_quality.wav'))
hr_quality_info = get_status_info(os.path.join(data_path, 'heart_rate_quality.wav'))

# plot
plt.figure()
plt.plot(x[:, 0], x[:, 1])
plt.plot(y[:, 0], y[:, 1])
plt.plot(z[:, 0], z[:, 1])
plt.title('acceleration')
plt.gca().set_xlim([0, 100])

plt.figure()
ax1 = plt.subplot(2, 1, 1)
plt.plot(ecg[:, 0], ecg[:, 1])
plt.plot(rr_interval[:, 0], rr_interval[:, 1] * 0 + 0, 'x')

plt.subplot(2, 1, 2, sharex=ax1)
plt.plot(heart_rate[:, 0], heart_rate[:, 1])
plt.ylabel('{} [{}]'.format(hr_info['filename'], hr_info['unit']))

# Plot without displaying hr that were detected as not clean
# filter data
hr_unreliable_key = next(a for a in hr_quality_info if a[0] == 'HR_STATUS_UNRELIABLE_RR')[1]
HR_60_hz_key = next(a for a in hr_quality_info if a[0] == 'HR_STATUS_50_60HZ')[1]
mask_key = hr_unreliable_key + HR_60_hz_key
filtered_hr = filter_data(heart_rate, heart_rate_quality, hr_unreliable_key)

plt.figure()
ax1 = plt.subplot(3, 1, 1)
plt.plot(ecg[:, 0], ecg[:, 1])
plt.ylabel('{}'.format(ecg_info['filename']))
plt.subplot(3, 1, 2, sharex=ax1)

plt.plot(heart_rate[:, 0], heart_rate[:, 1])
plt.ylabel('{} [{}]'.format(hr_info['filename'], hr_info['unit']))
plt.subplot(3, 1, 3, sharex=ax1)
plt.plot(filtered_hr[:, 0], filtered_hr[:, 1])
plt.ylabel('{} clean'.format(hr_info['filename'], hr_info['unit']))

plt.show()
